==> haskell-list-t-1.0.5.7-55.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.7
visibility:           public
id:                   list-t-1.0.5.7-AhA7x2MdeKdKv2uigYKj0T
key:                  list-t-1.0.5.7-AhA7x2MdeKdKv2uigYKj0T
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  5111e702766ba4dfc8710d9dd7576a2a
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.7-AhA7x2MdeKdKv2uigYKj0T
depends:
    base-4.18.2.1 foldl-1.4.18-DnwxI7jar0n9jaHnbNBdzr
    logict-0.8.2.0-IuAOa7GKoiODJvNxdRS5Nd
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-list-t-1.0.5.7-56-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.7
visibility:           public
id:                   list-t-1.0.5.7-FrIBwXDu8V5JPdGMNO7zz5
key:                  list-t-1.0.5.7-FrIBwXDu8V5JPdGMNO7zz5
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  efde059fa00bd3c45bfc49d53ab9579e
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.7-FrIBwXDu8V5JPdGMNO7zz5
depends:
    base-4.18.2.1 foldl-1.4.18-c4zLrEmO0CGifNSU6CYor
    logict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
    mmorph-1.2.1-FckgyjrzQqj9FpiKudKdHK
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
